Learn R Programming

AzureStor (version 1.0.0)

download_from_url: Generic upload and download

Description

Generic upload and download

Usage

download_from_url(src, dest, key = NULL, sas = NULL, ...,
  overwrite = FALSE)

upload_to_url(src, dest, key = NULL, sas = NULL, ...)

Arguments

src, dest

The source and destination files/URLs. Paths are allowed.

key, sas

Authentication arguments: an access key or a shared access signature (SAS). If a key is is provided, the SAS is not used. If neither an access key nor a SAS are provided, only public (anonymous) access to the share is possible.

...

Further arguments to pass to lower-level functions.

overwrite

For downloading, whether to overwrite any destination files that exist.

Details

These functions allow you to transfer files to and from a storage account, given the URL of the destination (for uploading) or source (for downloading). They dispatch to upload_azure_file/download_azure_file for a file storage URL and upload_blob/download_blob for a blob storage URL respectively.

You can provide a SAS either as part of the URL itself, or in the sas argument.

See Also

download_azure_file, download_blob, az_storage

Examples

Run this code
# NOT RUN {
# authenticated download with an access key
download_from_url("https://mystorage.blob.core.windows.net/mycontainer/bigfile.zip",
                  "~/bigfile.zip",
                  key="access_key")

# }

Run the code above in your browser using DataLab