Create a storage endpoint object, for interacting with blob, file, table, queue or ADLSgen2 storage. Currently (as of December 2018) ADLSgen2 is in general-access public preview.
storage_endpoint(endpoint, key = NULL, sas = NULL,
api_version = getOption("azure_storage_api_version"))blob_endpoint(endpoint, key = NULL, sas = NULL,
api_version = getOption("azure_storage_api_version"))
file_endpoint(endpoint, key = NULL, sas = NULL,
api_version = getOption("azure_storage_api_version"))
adls_endpoint(endpoint, key = NULL, sas = NULL,
api_version = getOption("azure_adls_api_version"))
# S3 method for storage_endpoint
print(x, ...)
# S3 method for adls_endpoint
print(x, ...)
The URL (hostname) for the endpoint. This must be of the form http[s]://{account-name}.{type}.{core-host-name}, where type is one of "dfs" (corresponding to ADLSgen2), "blob", "file", "queue" or "table". On the public Azure cloud, endpoints will be of the form https://{account-name}.{type}.core.windows.net.
The access key for the storage account.
A shared access signature (SAS) for the account. If key is also provided, the SAS is not used. If neither key nor sas are provided, only public (anonymous) access to the endpoint is possible. Note that authentication with a SAS is not supported by ADLSgen2.
The storage API version to use when interacting with the host. Defaults to "2018-06-17" for the ADLSgen2 endpoint, and "2018-03-28" for the others.
For the print method, a storage endpoint object.
For the print method, further arguments passed to lower-level functions.
storage_endpoint returns an object of S3 class "adls_endpoint", "blob_endpoint", "file_endpoint", "queue_endpoint" or "table_endpoint" depending on the type of endpoint. All of these also inherit from class "storage_endpoint". adls_endpoint, blob_endpoint and file_endpoint return an object of the respective class.
Currently AzureStor only includes methods for interacting with ADLSgen2 (experimental), blob and file storage.
Currently (as of December 2018), if the storage account has hierarchical namespaces enabled, the blob API for the account is disabled. The blob endpoint is still accessible, but blob operations on the endpoint will fail. Full interoperability between blobs and ADLS is planned for 2019.
This is the starting point for the client-side storage interface in AzureRMR. storage_endpoint is a generic function to create an endpoint for any type of Azure storage while adls_endpoint, blob_endpoint and file_endpoint create endpoints for those types.
create_storage_account, adls_filesystem, create_adls_filesystem, file_share, create_file_share, blob_container, create_blob_container
# NOT RUN {
# obtaining an endpoint from the storage account resource object
endp <- stor$get_blob_endpoint()
# creating an endpoint standalone
endp <- blob_endpoint("https://mystorage.blob.core.windows.net/", key="access_key")
# }
Run the code above in your browser using DataLab